@@ -20,7 +20,7 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-__version__ = '1.1.5'  # Remember to change in setup.py as well!
+__version__ = '1.2.0'
 __author__ = 'Raphaël Barrois <raphael.barrois@polytechnique.org>'
 
 from base import (
@@ -60,6 +60,7 @@ from declarations import (
     SelfAttribute,
     ContainerAttribute,
     SubFactory,
+    CircularSubFactory,
     PostGeneration,
     RelatedFactory,
 
